Line Charts
===========

Line Charts
-----------

Line charts allow data to be plotted against a fixed axis. They are similar
to scatter charts, the main difference is that with line charts each data
series is plotted against the same values. Different kinds of axes can be
used for the secondary axes.

Similar to bar charts there are three kinds of line charts: standard, stacked
and percentStacked.


.. literalinclude:: line.py


.. image:: line.png
   :alt: "Sample line charts"


3D Line Charts
--------------

In 3D line charts the third axis is the same as the legend for the series.


.. literalinclude:: line3D.py


.. image:: line3D.png
   :alt: "Sample 3D line chart"
